"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = exports.DefaultExpandable = void 0;

var _react = _interopRequireDefault(require("react"));

var _styleContainer = require("@cloudflare/style-container");

var _Cell = _interopRequireDefault(require("./Cell"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _extends() { _extends = Object.assign ? Object.assign.bind() : function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); enumerableOnly && (symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; })), keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = null != arguments[i] ? arguments[i] : {}; i % 2 ? ownKeys(Object(source), !0).forEach(function (key) { _defineProperty(target, key, source[key]); }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)) : ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } return target; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

var RowWrapper = (0, _styleContainer.createStyledComponent)(function (_ref) {
  var index = _ref.index,
      theme = _ref.theme,
      rowHighlight = _ref.rowHighlight,
      striped = _ref.striped,
      expandable = _ref.expandable,
      disabled = _ref.disabled,
      isSelected = _ref.isSelected,
      isLoading = _ref.isLoading,
      rowStyle = _ref.rowStyle;
  return _objectSpread(_objectSpread(_objectSpread(_objectSpread(_objectSpread(_objectSpread(_objectSpread({
    position: 'relative',
    backgroundColor: theme.colors.background
  }, index > 0 && {
    borderTop: "1px solid ".concat(theme.colors.gray[7])
  }), isSelected && {
    backgroundColor: 'blue.9'
  }), !isLoading && disabled && {
    backgroundColor: 'gray.9'
  }), expandable && {
    cursor: 'pointer'
  }), striped && index % 2 !== 0 ? {
    backgroundColor: 'gray.8'
  } : {}), rowHighlight ? {
    transition: 'background-color 0.07s ease-out',
    '&:hover': {
      backgroundColor: 'gray.7'
    }
  } : {}), rowStyle || {});
});
var DefaultExpandable = (0, _styleContainer.createStyledComponent)(function (_ref2) {
  var theme = _ref2.theme;
  return {
    position: 'sticky',
    left: 0,
    px: 1,
    '&:before': {
      content: '""',
      position: 'absolute',
      left: 0,
      top: 0,
      height: '100%',
      width: '4px',
      backgroundColor: theme.colors.blue[3],
      zIndex: 1
    }
  };
});
exports.DefaultExpandable = DefaultExpandable;

var Row = function Row(_ref3) {
  var row = _ref3.row,
      rowId = _ref3.rowId,
      rowStyle = _ref3.rowStyle,
      isLoading = _ref3.isLoading,
      expandable = _ref3.expandable,
      isRowExpandable = _ref3.isRowExpandable,
      isRowSelectable = _ref3.isRowSelectable,
      onlyOneExpanding = _ref3.onlyOneExpanding,
      toggleAllRowsExpanded = _ref3.toggleAllRowsExpanded,
      striped = _ref3.striped,
      rowHighlight = _ref3.rowHighlight,
      rowIndex = _ref3.rowIndex,
      onRowClick = _ref3.onRowClick,
      containerWidth = _ref3.containerWidth,
      disabled = _ref3.disabled,
      testId = _ref3.testId;
  var isExpandable = typeof isRowExpandable === 'function' && !!expandable ? isRowExpandable({
    row: row
  }) : !!expandable;

  var onClickFn = function onClickFn() {
    onRowClick({
      isExpanding: !row.isExpanded,
      row: row
    });

    if (onlyOneExpanding && !row.isExpanded) {
      toggleAllRowsExpanded(false);
      row.toggleRowExpanded(true);
    } else {
      row.toggleRowExpanded();
    }
  };

  var ariaProps = isExpandable ? {
    tabIndex: 0,
    'aria-expanded': !!row.isExpanded,
    onClick: onClickFn,
    onKeyDown: function onKeyDown(event) {
      if (event.key === 'Enter' || event.key === ' ') {
        event.preventDefault();
        onClickFn();
      }
    }
  } : {};
  return /*#__PURE__*/_react.default.createElement(RowWrapper, {
    "data-testid": testId,
    index: rowIndex,
    rowStyle: rowStyle,
    rowHighlight: rowHighlight,
    striped: striped,
    expandable: isExpandable,
    disabled: disabled,
    isSelected: row.isSelected,
    isLoading: isLoading
  }, /*#__PURE__*/_react.default.createElement("div", _extends({}, row.getRowProps(), ariaProps), row.cells.map(function (cell, index) {
    var _cell$getCellProps;

    return /*#__PURE__*/_react.default.createElement(_Cell.default, {
      key: (_cell$getCellProps = cell.getCellProps()) === null || _cell$getCellProps === void 0 ? void 0 : _cell$getCellProps.key,
      id: "".concat(rowId, "_cell_").concat(index),
      isLoading: isLoading // @ts-ignore
      ,
      cell: cell,
      isExpandable: isExpandable,
      isRowSelectable: isRowSelectable
    });
  })), row.isExpanded && !isLoading && ( // @ts-ignore
  expandable === null || expandable === void 0 ? void 0 : expandable({
    row: row,
    maxWidth: containerWidth
  })));
};

var _default = Row;
exports.default = _default;