import React from 'react';
import { Cell as ReactTableCell } from 'react-table';
import { Div } from '@cloudflare/elements';
import { isRowActions, EXPANDABLE_ID, SELECTABLE_ID } from './Table';
import { DefaultCell } from './CellStyles';
import { SkeletonBlock } from '@cloudflare/component-loading';

type CellProps = {
  cell: ReactTableCell;
  id: string;
  isLoading?: boolean;
  isExpandable?: boolean;
  isRowSelectable?: (row: any) => boolean;
};

const Cell = ({
  cell,
  id,
  isLoading,
  isExpandable,
  isRowSelectable
}: CellProps) => {
  if (isLoading && !isRowActions(cell.column.id))
    return (
      <Div id={id} {...cell.getCellProps({ style: { display: 'flex' } })}>
        <DefaultCell>
          <SkeletonBlock
            height="16px"
            width={`${Math.floor(Math.random() * (90 - 20 + 1)) + 20}%`}
          />
        </DefaultCell>
      </Div>
    );

  if (cell.column.id === EXPANDABLE_ID && !isExpandable)
    return (
      <Div
        id={id}
        {...cell.getCellProps({
          style: { display: 'flex', flex: '0 0 auto' }
        })}
      >
        <DefaultCell />
      </Div>
    );

  if (cell.column.id === SELECTABLE_ID || cell.column.id === EXPANDABLE_ID)
    return (
      <Div
        id={id}
        {...cell.getCellProps({
          style: { flex: '0 0 auto', display: 'flex', alignItems: 'center' }
        })}
      >
        {cell.render('Cell', { isRowSelectable })}
      </Div>
    );

  return (
    <Div
      id={id}
      {...cell.getCellProps({
        style: { display: 'flex', alignItems: 'center' }
      })}
    >
      {cell.render('Cell')}
    </Div>
  );
};

export default Cell;
